@@ -187,8 +187,11 @@ std::pair<const Isa*, const Isa*> Isa::supportedIsas() {
     {"gfx1033",                "gfx1033",   true,  false,   10, 3,  3,    NONE,   NONE, 2,    32,   1,    256,    64 * Ki, 32},
     {"gfx1034",                "gfx1034",   true,  true,    10, 3,  4,    NONE,   NONE, 2,    32,   1,    256,    64 * Ki, 32},
     {"gfx1035",                "gfx1035",   true,  true,    10, 3,  5,    NONE,   NONE, 2,    32,   1,    256,    64 * Ki, 32},
+    {"gfx1036",                "gfx1036",   true,  true,    10, 3,  6,    NONE,   NONE, 2,    32,   1,    256,    64 * Ki, 32},
     {"gfx1100",                "gfx1100",   true,  true,    11, 0,  0,    NONE,   NONE, 2,    32,   1,    256,    64 * Ki, 32},
+    {"gfx1101",                "gfx1101",   true,  true,    11, 0,  1,    NONE,   NONE, 2,    32,   1,    256,    64 * Ki, 32},
     {"gfx1102",                "gfx1102",   true,  true,    11, 0,  2,    NONE,   NONE, 2,    32,   1,    256,    64 * Ki, 32},
+    {"gfx1103",                "gfx1103",   true,  true,    11, 0,  3,    NONE,   NONE, 2,    32,   1,    256,    64 * Ki, 32},
   };
   return std::make_pair(std::begin(supportedIsas_), std::end(supportedIsas_));
 }
@@ -393,6 +396,7 @@ bool Device::BlitProgram::create(amd::Device* device, const std::string& extraKe
                                  const std::string& extraOptions) {
   std::vector<amd::Device*> devices;
   devices.push_back(device);
+  int32_t retval = CL_SUCCESS;
   std::string kernels(device::BlitLinearSourceCode);
   std::string image_kernels(device::BlitImageSourceCode);
 
@@ -407,6 +411,8 @@ bool Device::BlitProgram::create(amd::Device* device, const std::string& extraKe
   // Create a program with all blit kernels
   program_ = new Program(*context_, kernels.c_str(), Program::OpenCL_C);
   if (program_ == nullptr) {
+    DevLogPrintfError("Program creation for Kernel: %s failed\n",
+                      kernels.c_str());
     return false;
   }
 
@@ -422,9 +428,10 @@ bool Device::BlitProgram::create(amd::Device* device, const std::string& extraKe
   if (!GPU_DUMP_BLIT_KERNELS) {
     opt += " -fno-enable-dump";
   }
-  if (CL_SUCCESS !=
-      program_->build(devices, opt.c_str(), nullptr, nullptr, GPU_DUMP_BLIT_KERNELS)) {
-    DevLogPrintfError("Build failed for Kernel: %s \n", kernels.c_str());
+  if ((retval = program_->build(devices, opt.c_str(), nullptr, nullptr, GPU_DUMP_BLIT_KERNELS))
+      != CL_SUCCESS) {
+    DevLogPrintfError("Build failed for Kernel: %s with error code %d\n",
+                      kernels.c_str(), retval);
     return false;
   }
   if (!program_->load()) {
@@ -530,7 +537,8 @@ bool Device::ValidateComgr() {
 #if defined(USE_COMGR_LIBRARY)
   // Check if Lightning compiler was requested
   if (settings_->useLightning_) {
-    std::call_once(amd::Comgr::initialized, amd::Comgr::LoadLib);
+    constexpr bool kComgrVersioned = false;
+    std::call_once(amd::Comgr::initialized, amd::Comgr::LoadLib, kComgrVersioned);
     // Use Lightning only if it's available
     settings_->useLightning_ = amd::Comgr::IsReady();
     return settings_->useLightning_;
@@ -562,6 +570,10 @@ bool Device::create(const Isa &isa) {
   if (nullptr == vaCacheMap_) {
     return false;
   }
+  // For OpenCl default stack size needs to be set to 16K
+  if (!amd::IS_HIP) {
+    stack_size_ = 16 * Ki;
+  }
   return true;
 }
 
