@@ -613,6 +613,8 @@ struct Info : public amd::EmbeddedObject {
 
   bool virtualMemoryManagement_; //!< Virtual memory management support
   size_t virtualMemAllocGranularity_; //!< virtual memory allocation size/addr granularity
+
+  uint32_t driverNodeId_;
 };
 
 //! Device settings
@@ -1716,6 +1718,11 @@ class Device : public RuntimeObject {
     return true;
   }
 
+  virtual bool allowPeerAccess(device::Memory* memory) const {
+    ShouldNotCallThis();
+    return true;
+  }
+
   bool enableP2P(amd::Device* ptrDev);
 
   bool disableP2P(amd::Device* ptrDev);
