@@ -615,7 +615,11 @@ hipError_t ihipLaunchKernel(const void* hostFunction, dim3 gridDim, dim3 blockDi
   int deviceId = hip::Stream::DeviceId(stream);
   hipError_t hip_error = PlatformState::instance().getStatFunc(&func, hostFunction, deviceId);
   if ((hip_error != hipSuccess) || (func == nullptr)) {
-    HIP_RETURN(hipErrorInvalidDeviceFunction);
+    if (hip_error == hipErrorSharedObjectInitFailed) {
+      return hip_error;
+    } else {
+      return hipErrorInvalidDeviceFunction;
+    }
   }
   size_t globalWorkSizeX = static_cast<size_t>(gridDim.x) * blockDim.x;
   size_t globalWorkSizeY = static_cast<size_t>(gridDim.y) * blockDim.y;
@@ -623,12 +627,12 @@ hipError_t ihipLaunchKernel(const void* hostFunction, dim3 gridDim, dim3 blockDi
   if (globalWorkSizeX > std::numeric_limits<uint32_t>::max() ||
       globalWorkSizeY > std::numeric_limits<uint32_t>::max() ||
       globalWorkSizeZ > std::numeric_limits<uint32_t>::max()) {
-    HIP_RETURN(hipErrorInvalidConfiguration);
+    return hipErrorInvalidConfiguration;
   }
-  HIP_RETURN(ihipModuleLaunchKernel(
+  return ihipModuleLaunchKernel(
       func, static_cast<uint32_t>(globalWorkSizeX), static_cast<uint32_t>(globalWorkSizeY),
       static_cast<uint32_t>(globalWorkSizeZ), blockDim.x, blockDim.y, blockDim.z, sharedMemBytes,
-      stream, args, nullptr, startEvent, stopEvent, flags));
+      stream, args, nullptr, startEvent, stopEvent, flags);
 }
 
 // conversion routines between float and half precision
@@ -889,7 +893,7 @@ hipError_t PlatformState::registerStatManagedVar(hip::Var* var) {
   return statCO_.registerStatManagedVar(var);
 }
 
-const char* PlatformState::getStatFuncName(const void* hostFunction) const {
+const char* PlatformState::getStatFuncName(const void* hostFunction) {
   return statCO_.getStatFuncName(hostFunction);
 }
 
